from django.conf.urls.defaults import patterns, url
from django.views.generic import DetailView, ListView

from .models import OnCall


urlpatterns = patterns('',
    url(r'^$',
        ListView.as_view(model=OnCall),
        name='on-calls'),
    url(r'^(?P<slug>[-\w\d]+)/$',
        DetailView.as_view(model=OnCall),
        name='on-call'),
    )



import datetime

from django.db import models


class OnCall (models.Model):
    slug = models.SlugField(
        verbose_name='on-call slot',
        help_text='Identify this among other possible on-call positions')
    rule = models.TextField(
        verbose_name='on-call rule',
        help_text=(
            'Python statement for determining the on-call admin.  '
            "Store the selected admin as 'on_call'."))

    def get_on_call(self, now=None):
        if now is None:
            now = datetime.datetime.now()
        exec(self.rule)
        if 'on_call' in locals():
            return on_call



"Point website users at configurable on-call administrators"

import codecs as _codecs
from distutils.core import setup
import os.path as _os_path

from django_on_call import __version__


_this_dir = _os_path.dirname(__file__)

setup(
    name='django-on-call',
    version=__version__,
    maintainer='W. Trevor King',
    maintainer_email='wking@tremily.us',
    url='https://github.com/wking/django-on-call',
    download_url='https://github.com/wking/django-on-call/archive/v{}.tar.gz'.format(__version__),
    license='BSD License',
    platforms=['all'],
    description=__doc__,
    long_description=_codecs.open(
        _os_path.join(_this_dir, 'README'), 'r', encoding='utf-8').read(),
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.2',
        'Programming Language :: Python :: 3.3',
        'Topic :: Software Development :: Libraries :: Python Modules',
        ],
    packages=['django_on_call'],
    provides=['django_on_call'],
    )



import datetime

from django.test import TestCase

from .models import OnCall


class SimpleTest(TestCase):
    def test_get_on_call(self):
        """Test the basic OnCall.get_on_call functionality
        """
        on_call = OnCall(slug='test', rule='on_call = "Alice"')
        self.assertEqual(on_call.get_on_call(), 'Alice')

    def test_weekly(self):
        """Test a week-on round robin
        """
        on_call = OnCall(slug='test', rule='\n'.join([
            'handlers = ["Alice", "Bob", "Charlie"]',
            'week = int(now.strftime("%W"))',
            'on_call = handlers[week % len(handlers)]',
            ]))
        for now, expected in [
                (datetime.datetime(2013, 1, 1), 'Alice'),
                (datetime.datetime(2013, 1, 8), 'Bob'),
                (datetime.datetime(2013, 1, 15), 'Charlie'),
                (datetime.datetime(2013, 1, 22), 'Alice'),
                ]:
            self.assertEqual(on_call.get_on_call(now=now), expected)
